From 9349f0ffaaede9744b8f33da28f7e57fa5cdeb40 Mon Sep 17 00:00:00 2001
From: Xiliang Chen <xlchen1291@gmail.com>
Date: Mon, 30 May 2022 22:11:21 +1200
Subject: [PATCH] use RuntimeDebug (#1306)

---
 cumulus/pallets/xcm/src/lib.rs | 5 ++---
 1 file changed, 2 insertions(+), 3 deletions(-)

diff --git a/cumulus/pallets/xcm/src/lib.rs b/cumulus/pallets/xcm/src/lib.rs
index 10c306f1be9..649bb5ad693 100644
--- a/cumulus/pallets/xcm/src/lib.rs
+++ b/cumulus/pallets/xcm/src/lib.rs
@@ -27,7 +27,7 @@ use cumulus_primitives_core::{
 use frame_support::dispatch::Weight;
 pub use pallet::*;
 use scale_info::TypeInfo;
-use sp_runtime::traits::BadOrigin;
+use sp_runtime::{traits::BadOrigin, RuntimeDebug};
 use sp_std::{convert::TryFrom, prelude::*};
 use xcm::{
 	latest::{ExecuteXcm, Outcome, Parent, Xcm},
@@ -77,8 +77,7 @@ pub mod pallet {
 	}
 
 	/// Origin for the parachains module.
 	#[derive(PartialEq, Eq, Clone, Encode, Decode, TypeInfo)]
 	#[cfg_attr(feature = "std", derive(Debug))]
 	#[pallet::origin]
 	pub enum Origin {
 		/// It comes from the (parent) relay chain.
@@ -77,8 +77,7 @@ pub mod pallet {
 
 	/// Origin for the parachains module.
-	#[derive(PartialEq, Eq, Clone, Encode, Decode, TypeInfo)]
-	#[cfg_attr(feature = "std", derive(Debug))]
+	#[derive(PartialEq, Eq, Clone, Encode, Decode, TypeInfo, RuntimeDebug)]
 	#[pallet::origin]
 	pub enum Origin {
-- 
GitLab